@@ -1,4 +1,4 @@
-# Copyright 2020 The TF-Coder Authors.
+# Copyright 2021 The TF-Coder Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -297,6 +297,14 @@ class Value(object):
     else:
       return tf_coder_utils.min_tensor_value(self.value)
 
+  @cache
+  def reduce_sum(self):
+    """Returns the sum of the wrapped value's elements."""
+    if self.is_sequence:
+      return sum(self.value)
+    else:
+      return float(tf.reduce_sum(tf.cast(self.value, tf.float32)))
+
   @cache
   def reduce_prod(self):
     """Returns the product of the wrapped value's elements."""
